@@ -20,7 +20,7 @@ public:
     explicit PassManager(QObject *parent = nullptr);
     ~PassManager();
 
-    enum {
+    enum Roles {
         PassRole = Qt::UserRole,
         PassIdRole,
         PassTypeRole,
@@ -30,6 +30,7 @@ public:
         SectionRole,
         ValidRangeLabelRole,
     };
+    Q_ENUM(Roles)
 
     enum PassType {
         ProgramMembership,
@@ -38,7 +39,7 @@ public:
     };
     Q_ENUM(PassType)
 
-    QString import(const QVariant &pass, const QString &id = {});
+    Q_INVOKABLE QString import(const QVariant &pass, const QString &id = {});
     QStringList import(const QVector<QVariant> &passes);
 
     /** Returns the pass id for the pass that is the closest match
